/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.client.extension.type.item.selector.web.internal.item.selector;

import com.liferay.client.extension.constants.ClientExtensionEntryConstants;
import com.liferay.client.extension.type.CET;
import com.liferay.client.extension.type.CETThemeFavicon;
import com.liferay.item.selector.ItemSelectorViewDescriptor;
import com.liferay.portal.kernel.json.JSONUtil;
import com.liferay.portal.kernel.util.LocaleUtil;

import java.util.Date;
import java.util.Locale;
import java.util.Objects;

/**
 * @author Víctor Galán
 */
public class CETItemDescriptor
	implements ItemSelectorViewDescriptor.ItemDescriptor {

	public CETItemDescriptor(CET cet) {
		_cet = cet;
	}

	@Override
	public String getIcon() {
		return "api-web";
	}

	@Override
	public String getImageURL() {
		return null;
	}

	@Override
	public Date getModifiedDate() {
		return null;
	}

	@Override
	public String getPayload() {
		return JSONUtil.put(
			"cetExternalReferenceCode", _cet.getExternalReferenceCode()
		).put(
			"name", _cet.getName(LocaleUtil.getMostRelevantLocale())
		).put(
			"type", _cet.getType()
		).put(
			"url",
			() -> {
				if (Objects.equals(
						_cet.getType(),
						ClientExtensionEntryConstants.TYPE_THEME_FAVICON)) {

					CETThemeFavicon cetThemeFavicon = (CETThemeFavicon)_cet;

					return cetThemeFavicon.getURL();
				}

				return null;
			}
		).toString();
	}

	@Override
	public String getSubtitle(Locale locale) {
		return _cet.getType();
	}

	@Override
	public String getTitle(Locale locale) {
		return _cet.getName(locale);
	}

	@Override
	public long getUserId() {
		return 0;
	}

	@Override
	public String getUserName() {
		return null;
	}

	@Override
	public boolean isCompact() {
		return true;
	}

	private final CET _cet;

}